==> alg-common-2.6.4-20190923.063343-12-sources.jar: cn/com/duiba/nezha/alg/common/model/activityselectconversionforms/ActivityData.java <==
package cn.com.duiba.nezha.alg.common.model.activityselectconversionforms;

public class ActivityData {

    long activityId;
    long slotId;
    long appId;
    Val hisRequest;
    Val hisClick;
    Val hisSend;
    Val hisCost;
    double changeScore; //历史转化分
    int activityTypeNew; //v3.5  新老活动类型: 0 新创建活动，1 新活动，2 老活动
    boolean isHot; //热点活动， true：热点活动，false：普通活动
    long uploadTime; //活动上架时间，微秒
    int subType = 0; //v4.0 皮肤含有ops或vm新活动 1;否则老活动 0
    boolean isExcellent; //v4.0 是否是优质活动
    double nPvClick; //v4.0 归一化每pv券点击
    double nPvCost; //v4.0 归一化每pv消耗
    double nCvrForm; //v4.0 归一化表单类cvr
    double nCvrNotForm; //v4.0 归一化非表单类cvr
    double nCvr; // v4.0 归一化转化率
    double score; //4.0 归一化得分

    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public long getSlotId() {
        return slotId;
    }

    public void setSlotId(long slotId) {
        this.slotId = slotId;
    }

    public long getAppId() {
        return appId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }


    public Val getHisRequest() {
        return hisRequest;
    }

    public void setHisRequest(Val hisRequest) {
        this.hisRequest = hisRequest;
    }

    public Val getHisClick() {
        return hisClick;
    }

    public void setHisClick(Val hisClick) {
        this.hisClick = hisClick;
    }

    public Val getHisSend() {
        return hisSend;
    }

    public void setHisSend(Val hisSend) {
        this.hisSend = hisSend;
    }

    public Val getHisCost() {
        return hisCost;
    }

    public void setHisCost(Val hisCost) {
        this.hisCost = hisCost;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public int getActivityTypeNew() {
        return activityTypeNew;
    }

    public void setActivityTypeNew(int activityTypeNew) {
        this.activityTypeNew = activityTypeNew;
    }

    public boolean isHot() {
        return isHot;
    }

    public void setHot(boolean hot) {
        isHot = hot;
    }

    public long getUploadTime() {
        return uploadTime;
    }

    public void setUploadTime(long uploadTime) {
        this.uploadTime = uploadTime;
    }

    public boolean isExcellent() {
        return isExcellent;
    }

    public void setExcellent(boolean excellent) {
        isExcellent = excellent;
    }

    public double getnPvClick() {
        return nPvClick;
    }

    public void setnPvClick(double nPvClick) {
        this.nPvClick = nPvClick;
    }

    public double getnPvCost() {
        return nPvCost;
    }

    public void setnPvCost(double nPvCost) {
        this.nPvCost = nPvCost;
    }

    public double getScore() {
        return score;
    }

    public void setScore(double score) {
        this.score = score;
    }

    public int getSubType() {
        return subType;
    }

    public void setSubType(int subType) {
        this.subType = subType;
    }

    public double getnCvrForm() {
        return nCvrForm;
    }

    public void setnCvrForm(double nCvrForm) {
        this.nCvrForm = nCvrForm;
    }

    public double getnCvrNotForm() {
        return nCvrNotForm;
    }

    public void setnCvrNotForm(double nCvrNotForm) {
        this.nCvrNotForm = nCvrNotForm;
    }

    public double getnCvr() {
        return nCvr;
    }

    public void setnCvr(double nCvr) {
        this.nCvr = nCvr;
    }

    @Override
    public String toString() {
        return "ActivityData{" +
                "activityId=" + activityId +
                ", slotId=" + slotId +
                ", appId=" + appId +
                ", hisRequest=" + hisRequest +
                ", hisClick=" + hisClick +
                ", hisSend=" + hisSend +
                ", hisCost=" + hisCost +
                ", changeScore=" + changeScore +
                ", activityTypeNew=" + activityTypeNew +
                ", isHot=" + isHot +
                ", uploadTime=" + uploadTime +
                ", subType=" + subType +
                ", isExcellent=" + isExcellent +
                ", nPvClick=" + nPvClick +
                ", nPvCost=" + nPvCost +
                ", nCvrForm=" + nCvrForm +
                ", nCvrNotForm=" + nCvrNotForm +
                ", nCvr=" + nCvr +
                ", score=" + score +
                '}';
    }
}

==> alg-common-3.1.1-20190520.071121-1-sources.jar: cn/com/duiba/nezha/alg/common/model/activityselectconversionforms/ActivityData.java <==
package cn.com.duiba.nezha.alg.common.model.activityselectconversionforms;

public class ActivityData {

    long activityId;
    long slotId;
    long appId;

    Val hisRequest;

    Val hisClick;
    Val hisSend;
    Val hisCost;
    double changeScore; //历史转化分

    int activityTypeNew; //v3.5  新老活动类型: 0 新创建活动，1 新活动，2 老活动
    boolean isHot = false; //热点活动， true：热点活动，false：普通活动
    long uploadTime = 0; //活动上架时间，微秒


    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public long getSlotId() {
        return slotId;
    }

    public void setSlotId(long slotId) {
        this.slotId = slotId;
    }

    public long getAppId() {
        return appId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }


    public Val getHisRequest() {
        return hisRequest;
    }

    public void setHisRequest(Val hisRequest) {
        this.hisRequest = hisRequest;
    }

    public Val getHisClick() {
        return hisClick;
    }

    public void setHisClick(Val hisClick) {
        this.hisClick = hisClick;
    }

    public Val getHisSend() {
        return hisSend;
    }

    public void setHisSend(Val hisSend) {
        this.hisSend = hisSend;
    }

    public Val getHisCost() {
        return hisCost;
    }

    public void setHisCost(Val hisCost) {
        this.hisCost = hisCost;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public int getActivityTypeNew() {
        return activityTypeNew;
    }

    public void setActivityTypeNew(int activityTypeNew) {
        this.activityTypeNew = activityTypeNew;
    }

    public boolean isHot() {
        return isHot;
    }

    public void setHot(boolean hot) {
        isHot = hot;
    }

    public long getUploadTime() {
        return uploadTime;
    }

    public void setUploadTime(long uploadTime) {
        this.uploadTime = uploadTime;
    }
}
